==> phpMinAdmin-1.9.1.zip: phpMinAdmin-1.9.1/lang/et.inc.php <==
<?php
$translations = array(
	'Login' => 'Logi sisse',
	'phpMinAdmin' => 'Andmebaasi haldaja',
	'Logout successful.' => 'Väljalogimine õnnestus.',
	'Invalid credentials.' => 'Ebasobivad andmed.',
	'Server' => 'Server',
	'Username' => 'Kasutajanimi',
	'Password' => 'Parool',
	'Select database' => 'Vali andmebaas',
	'Invalid database.' => 'Sobimatu andmebaas.',
	'Create new database' => 'Loo uus andmebaas',
	'Table has been dropped.' => 'Tabel on edukalt kustutatud.',
	'Table has been altered.' => 'Tabeli andmed on edukalt muudetud.',
	'Table has been created.' => 'Tabel on edukalt loodud.',
	'Alter table' => 'Muuda tabeli struktuuri',
	'Create table' => 'Loo uus tabel',
	'Table name' => 'Tabeli nimi',
	'engine' => 'Mootor',
	'collation' => 'Tähetabel',
	'Column name' => 'Veeru nimi',
	'Type' => 'Tüüp',
	'Length' => 'Pikkus',
	'NULL' => 'NULL',
	'Auto Increment' => 'Automaatselt suurenev',
	'Options' => 'Valikud',
	'Save' => 'Sisesta',
	'Drop' => 'Kustuta',
	'Database has been dropped.' => 'Andmebaas on edukalt kustutatud.',
	'Database has been created.' => 'Andmebaas on edukalt loodud.',
	'Database has been renamed.' => 'Andmebaas on edukalt ümber nimetatud.',
	'Database has been altered.' => 'Andmebaasi struktuuri uuendamine õnnestus.',
	'Alter database' => 'Muuda andmebaasi',
	'Create database' => 'Loo uus andmebaas',
	'SQL command' => 'SQL-Päring',
	'Dump' => 'Ekspordi',
	'Logout' => 'Logi välja',
	'database' => 'Andmebaas',
	'Use' => 'Kasuta',
	'No tables.' => 'Tabeleid ei leitud.',
	'select' => 'kuva',
	'Create new table' => 'Loo uus tabel',
	'Item has been deleted.' => 'Kustutamine õnnestus.',
	'Item has been updated.' => 'Uuendamine õnnestus.',
	'Item has been inserted.' => 'Lisamine õnnestus.',
	'Edit' => 'Muuda',
	'Insert' => 'Sisesta',
	'Save and insert next' => 'Sisesta ja lisa järgmine',
	'Delete' => 'Kustuta',
	'Database' => 'Andmebaas',
	'Routines' => 'Protseduurid',
	'Indexes has been altered.' => 'Indeksite andmed on edukalt uuendatud.',
	'Indexes' => 'Indeksid',
	'Alter indexes' => 'Muuda indekseid',
	'Add next' => 'Lisa järgmine',
	'Language' => 'Keel',
	'Select' => 'Kuva',
	'New item' => 'Lisa kirje',
	'Search' => 'Otsi',
	'Sort' => 'Sordi',
	'DESC' => 'Kahanevalt',
	'Limit' => 'Piira kirjete hulka',
	'No rows.' => 'Sissekanded puuduvad.',
	'Action' => 'Tegevus',
	'edit' => 'muuda',
	'Page' => 'Lehekülg',
	'Query executed OK, %d row(s) affected.' => array('Päring õnnestus, mõjutatatud ridu: %d.', 'Päring õnnestus, mõjutatatud ridu: %d'),
	'Error in query' => 'SQL-päringus esines viga',
	'Execute' => 'Käivita',
	'Table' => 'Tabel',
	'Foreign keys' => 'Võõrvõtmed (foreign key)',
	'Triggers' => 'Päästikud (trigger)',
	'View' => 'Vaata',
	'Unable to select the table' => 'Tabeli valimine ebaõnnestus',
	'Invalid CSRF token. Send the form again.' => 'Sobimatu CSRF, palun saadke vorm uuesti.',
	'Comment' => 'Kommentaar',
	'Default values has been set.' => 'Vaimimisi väärtused on edukalt määratud.',
	'Default values' => 'Vaikimisi väärtused',
	'BOOL' => 'Jah/Ei (BOOL)',
	'Show column comments' => 'Kuva veeru kommentaarid',
	'%d byte(s)' => array('%d bait', '%d baiti'),
	'No commands to execute.' => 'Käsk puudub.',
	'Unable to upload a file.' => 'Faili üleslaadimine pole võimalik.',
	'File upload' => 'Faili üleslaadimine',
	'File uploads are disabled.' => 'Faili üleslaadimine on keelatud.',
	'Routine has been called, %d row(s) affected.' => array('Protseduur täideti edukalt, mõjutatud ridu: %d.', 'Protseduur täideti edukalt, mõjutatud ridu: %d'),
	'Call' => 'Käivita',
	'No MySQL extension' => 'Ei leitud MySQL laiendust',
	'None of supported PHP extensions (%s) are available.' => 'Serveris pole ühtegi toetatud PHP laiendustest (%s).',
	'Sessions must be enabled.' => 'Sessioonid peavad olema lubatud.',
	'Session expired, please login again.' => 'Sessioon on aegunud, palun logige uuesti sisse.',
	'Text length' => 'Teksti pikkus',
	'Syntax highlighting' => 'Värvi süntaks',
	'Foreign key has been dropped.' => 'Võõrvõti on edukalt kustutatud.',
	'Foreign key has been altered.' => 'Võõrvõtme andmed on edukalt muudetud.',
	'Foreign key has been created.' => 'Võõrvõri on edukalt loodud.',
	'Foreign key' => 'Võõrvõti',
	'Target table' => 'Siht-tabel',
	'Change' => 'Muuda',
	'Source' => 'Allikas',
	'Target' => 'Sihtkoht',
	'Add column' => 'Lisa veerg',
	'Alter' => 'Muuda',
	'Add foreign key' => 'Lisa võõrvõti',
	'ON DELETE' => 'ON DELETE',
	'ON UPDATE' => 'ON UPDATE',
	'Index Type' => 'Indeksi tüüp',
	'Column (length)' => 'Veerg (pikkus)',
	'View has been dropped.' => 'Vaade (VIEW) on edukalt kustutatud.',
	'View has been altered.' => 'Vaade (VIEW) on edukalt muudetud.',
	'View has been created.' => 'Vaade (VIEW) on edukalt loodud.',
	'Alter view' => 'Muuda vaadet (VIEW)',
	'Create view' => 'Loo uus vaade (VIEW)',
	'Name' => 'Nimi',
	'Process list' => 'Protsesside nimekiri',
	'%d process(es) has been killed.' => array('Protsess on edukalt peatatud (%d).', 'Valitud protsessid (%d) on edukalt peatatud'),
	'Kill' => 'Peata',
	'IN-OUT' => 'IN-OUT',
	'Parameter name' => 'Parameetri nimi',
	'Database schema' => 'Andmebaasi skeem',
	'Create procedure' => 'Loo uus protseduur',
	'Create function' => 'Loo uus funktsioon',
	'Routine has been dropped.' => 'Protseduur on edukalt kustutatud.',
	'Routine has been altered.' => 'Protseduuri andmed on edukalt muudetud.',
	'Routine has been created.' => 'Protseduur on edukalt loodud.',
	'Alter function' => 'Muuda funktsiooni',
	'Alter procedure' => 'Muuda protseduuri',
	'Return type' => 'Tagastustüüp',
	'Add trigger' => 'Lisa päästik (TRIGGER)',
	'Trigger has been dropped.' => 'Päästik on edukalt kustutatud.',
	'Trigger has been altered.' => 'Päästiku andmed on edukalt uuendatud.',
	'Trigger has been created.' => 'Uus päästik on edukalt loodud.',
	'Alter trigger' => 'Muuda päästiku andmeid',
	'Create trigger' => 'Loo uus päästik (TRIGGER)',
	'Time' => 'Aeg',
	'Event' => 'Sündmus',
	'%d row(s)' => array('%d rida', '%d rida'),
	'ON UPDATE CURRENT_TIMESTAMP' => 'ON UPDATE CURRENT_TIMESTAMP',
	'Remove' => 'Eemalda',
	'Are you sure?' => 'Kas oled kindel?',
	'Privileges' => 'Õigused',
	'Create user' => 'Loo uus kasutaja',
	'User has been dropped.' => 'Kasutaja on edukalt kustutatud.',
	'User has been altered.' => 'Kasutaja andmed on edukalt muudetud.',
	'User has been created.' => 'Kasutaja on edukalt lisatud.',
	'Hashed' => 'Häshitud (Hashed)',
	'Column' => 'Veerg',
	'Routine' => 'Protseduur',
	'Grant' => 'Anna',
	'Revoke' => 'Eemalda',
	'MySQL version: %s through PHP extension %s' => 'MySQL versioon: %s, kasutatud PHP moodul: %s',
	'Logged as: %s' => 'Sisse logitud: %s',
	'Too big POST data. Reduce the data or increase the "post_max_size" configuration directive.' => 'POST-andmete maht on liialt suur. Palun vähendage andmeid või suurendage "post_max_size" php-seadet.',
	'Move up' => 'Liiguta ülespoole',
	'Move down' => 'Liiguta allapoole',
	'Export' => 'Ekspordi',
	'skip' => 'ignoreeri',
	'Tables' => 'Tabelid',
	'Structure' => 'Struktuur',
	'Data' => 'Andmed',
	'Output' => 'Väljund',
	'open' => 'näita brauseris',
	'save' => 'salvesta failina',
	'Format' => 'Formaat',
	'SQL' => 'SQL',
	'CSV' => 'CSV',
	'Functions' => 'Funktsioonid',
	'Aggregation' => 'Liitmine',
	'Event has been dropped.' => 'Sündmus on edukalt kustutatud.',
	'Event has been altered.' => 'Sündmuse andmed on edukalt uuendatud.',
	'Event has been created.' => 'Sündmus on edukalt loodud.',
	'Alter event' => 'Muuda sündmuse andmeid',
	'Create event' => 'Loo uus sündmus (EVENT)',
	'Start' => 'Alusta',
	'End' => 'Lõpeta',
	'Every' => 'Iga',
	'Status' => 'Staatus',
	'On completion preserve' => 'Lõpetamisel jäta sündmus alles',
	'Events' => 'Sündmused (EVENTS)',
	'Schedule' => 'Ajakava',
	'At given time' => 'Antud ajahetkel',
	'Save and continue edit' => 'Salvesta ja jätka muutmist',
	'original' => 'originaal',
	'Tables have been truncated.' => 'Validud tabelid on edukalt tühjendatud.',
	'Tables have been moved.' => 'Valitud tabelid on edukalt liigutatud.',
	'Tables have been dropped.' => 'Valitud tabelid on edukalt kustutatud.',
	'Tables and views' => 'Tabelid ja vaated',
	'Engine' => 'Implementatsioon',
	'Collation' => 'Tähetabel',
	'Data Length' => 'Andmete pikkus',
	'Index Length' => 'Indeksi pikkus',
	'Data Free' => 'Vaba ruumi',
	'Rows' => 'Ridu',
	',' => ',',
	'Analyze' => 'Analüüsi',
	'Optimize' => 'Optimeeri',
	'Check' => 'Kontrolli',
	'Repair' => 'Paranda',
	'Truncate' => 'Tühjenda',
	'Move to other database' => 'Liiguta teise andmebaasi',
	'Move' => 'Liiguta',
	'%d item(s) have been affected.' => array('Mõjutatud kirjeid: %d.', 'Mõjutatud kirjeid: %d.'),
	'whole result' => 'Täielikud tulemused',
	'clone' => 'Klooni',
	'Clone' => 'Kloon',
);

==> phpMinAdmin-1.10.0.zip: phpMinAdmin-1.10.0/lang/et.inc.php <==
<?php
$translations = array(
	'Login' => 'Logi sisse',
	'phpMinAdmin' => 'Andmebaasi haldaja',
	'Logout successful.' => 'Väljalogimine õnnestus.',
	'Invalid credentials.' => 'Ebasobivad andmed.',
	'Server' => 'Server',
	'Username' => 'Kasutajanimi',
	'Password' => 'Parool',
	'Select database' => 'Vali andmebaas',
	'Invalid database.' => 'Sobimatu andmebaas.',
	'Create new database' => 'Loo uus andmebaas',
	'Table has been dropped.' => 'Tabel on edukalt kustutatud.',
	'Table has been altered.' => 'Tabeli andmed on edukalt muudetud.',
	'Table has been created.' => 'Tabel on edukalt loodud.',
	'Alter table' => 'Muuda tabeli struktuuri',
	'Create table' => 'Loo uus tabel',
	'Table name' => 'Tabeli nimi',
	'engine' => 'Mootor',
	'collation' => 'Tähetabel',
	'Column name' => 'Veeru nimi',
	'Type' => 'Tüüp',
	'Length' => 'Pikkus',
	'NULL' => 'NULL',
	'Auto Increment' => 'Automaatselt suurenev',
	'Options' => 'Valikud',
	'Save' => 'Sisesta',
	'Drop' => 'Kustuta',
	'Database has been dropped.' => 'Andmebaas on edukalt kustutatud.',
	'Database has been created.' => 'Andmebaas on edukalt loodud.',
	'Database has been renamed.' => 'Andmebaas on edukalt ümber nimetatud.',
	'Database has been altered.' => 'Andmebaasi struktuuri uuendamine õnnestus.',
	'Alter database' => 'Muuda andmebaasi',
	'Create database' => 'Loo uus andmebaas',
	'SQL command' => 'SQL-Päring',
	'Dump' => 'Ekspordi',
	'Logout' => 'Logi välja',
	'database' => 'Andmebaas',
	'Use' => 'Kasuta',
	'No tables.' => 'Tabeleid ei leitud.',
	'select' => 'kuva',
	'Create new table' => 'Loo uus tabel',
	'Item has been deleted.' => 'Kustutamine õnnestus.',
	'Item has been updated.' => 'Uuendamine õnnestus.',
	'Item has been inserted.' => 'Lisamine õnnestus.',
	'Edit' => 'Muuda',
	'Insert' => 'Sisesta',
	'Save and insert next' => 'Sisesta ja lisa järgmine',
	'Delete' => 'Kustuta',
	'Database' => 'Andmebaas',
	'Routines' => 'Protseduurid',
	'Indexes has been altered.' => 'Indeksite andmed on edukalt uuendatud.',
	'Indexes' => 'Indeksid',
	'Alter indexes' => 'Muuda indekseid',
	'Add next' => 'Lisa järgmine',
	'Language' => 'Keel',
	'Select' => 'Kuva',
	'New item' => 'Lisa kirje',
	'Search' => 'Otsi',
	'Sort' => 'Sordi',
	'DESC' => 'Kahanevalt',
	'Limit' => 'Piira kirjete hulka',
	'No rows.' => 'Sissekanded puuduvad.',
	'Action' => 'Tegevus',
	'edit' => 'muuda',
	'Page' => 'Lehekülg',
	'Query executed OK, %d row(s) affected.' => array('Päring õnnestus, mõjutatatud ridu: %d.', 'Päring õnnestus, mõjutatatud ridu: %d.'),
	'Error in query' => 'SQL-päringus esines viga',
	'Execute' => 'Käivita',
	'Table' => 'Tabel',
	'Foreign keys' => 'Võõrvõtmed (foreign key)',
	'Triggers' => 'Päästikud (trigger)',
	'View' => 'Vaata',
	'Unable to select the table' => 'Tabeli valimine ebaõnnestus',
	'Invalid CSRF token. Send the form again.' => 'Sobimatu CSRF, palun saadke vorm uuesti.',
	'Comment' => 'Kommentaar',
	'Default values has been set.' => 'Vaimimisi väärtused on edukalt määratud.',
	'Default values' => 'Vaikimisi väärtused',
	'BOOL' => 'Jah/Ei (BOOL)',
	'Show column comments' => 'Kuva veeru kommentaarid',
	'%d byte(s)' => array('%d bait', '%d baiti'),
	'No commands to execute.' => 'Käsk puudub.',
	'Unable to upload a file.' => 'Faili üleslaadimine pole võimalik.',
	'File upload' => 'Faili üleslaadimine',
	'File uploads are disabled.' => 'Faili üleslaadimine on keelatud.',
	'Routine has been called, %d row(s) affected.' => array('Protseduur täideti edukalt, mõjutatud ridu: %d.', 'Protseduur täideti edukalt, mõjutatud ridu: %d.'),
	'Call' => 'Käivita',
	'No MySQL extension' => 'Ei leitud MySQL laiendust',
	'None of supported PHP extensions (%s) are available.' => 'Serveris pole ühtegi toetatud PHP laiendustest (%s).',
	'Sessions must be enabled.' => 'Sessioonid peavad olema lubatud.',
	'Session expired, please login again.' => 'Sessioon on aegunud, palun logige uuesti sisse.',
	'Text length' => 'Teksti pikkus',
	'Syntax highlighting' => 'Värvi süntaks',
	'Foreign key has been dropped.' => 'Võõrvõti on edukalt kustutatud.',
	'Foreign key has been altered.' => 'Võõrvõtme andmed on edukalt muudetud.',
	'Foreign key has been created.' => 'Võõrvõri on edukalt loodud.',
	'Foreign key' => 'Võõrvõti',
	'Target table' => 'Siht-tabel',
	'Change' => 'Muuda',
	'Source' => 'Allikas',
	'Target' => 'Sihtkoht',
	'Add column' => 'Lisa veerg',
	'Alter' => 'Muuda',
	'Add foreign key' => 'Lisa võõrvõti',
	'ON DELETE' => 'ON DELETE',
	'ON UPDATE' => 'ON UPDATE',
	'Index Type' => 'Indeksi tüüp',
	'Column (length)' => 'Veerg (pikkus)',
	'View has been dropped.' => 'Vaade (VIEW) on edukalt kustutatud.',
	'View has been altered.' => 'Vaade (VIEW) on edukalt muudetud.',
	'View has been created.' => 'Vaade (VIEW) on edukalt loodud.',
	'Alter view' => 'Muuda vaadet (VIEW)',
	'Create view' => 'Loo uus vaade (VIEW)',
	'Name' => 'Nimi',
	'Process list' => 'Protsesside nimekiri',
	'%d process(es) has been killed.' => array('Protsess on edukalt peatatud (%d).', 'Valitud protsessid (%d) on edukalt peatatud.'),
	'Kill' => 'Peata',
	'IN-OUT' => 'IN-OUT',
	'Parameter name' => 'Parameetri nimi',
	'Database schema' => 'Andmebaasi skeem',
	'Create procedure' => 'Loo uus protseduur',
	'Create function' => 'Loo uus funktsioon',
	'Routine has been dropped.' => 'Protseduur on edukalt kustutatud.',
	'Routine has been altered.' => 'Protseduuri andmed on edukalt muudetud.',
	'Routine has been created.' => 'Protseduur on edukalt loodud.',
	'Alter function' => 'Muuda funktsiooni',
	'Alter procedure' => 'Muuda protseduuri',
	'Return type' => 'Tagastustüüp',
	'Add trigger' => 'Lisa päästik (TRIGGER)',
	'Trigger has been dropped.' => 'Päästik on edukalt kustutatud.',
	'Trigger has been altered.' => 'Päästiku andmed on edukalt uuendatud.',
	'Trigger has been created.' => 'Uus päästik on edukalt loodud.',
	'Alter trigger' => 'Muuda päästiku andmeid',
	'Create trigger' => 'Loo uus päästik (TRIGGER)',
	'Time' => 'Aeg',
	'Event' => 'Sündmus',
	'%d row(s)' => array('%d rida', '%d rida'),
	'around %s' => 'umbes %s',
	'ON UPDATE CURRENT_TIMESTAMP' => 'ON UPDATE CURRENT_TIMESTAMP',
	'Remove' => 'Eemalda',
	'Are you sure?' => 'Kas oled kindel?',
	'Privileges' => 'Õigused',
	'Create user' => 'Loo uus kasutaja',
	'User has been dropped.' => 'Kasutaja on edukalt kustutatud.',
	'User has been altered.' => 'Kasutaja andmed on edukalt muudetud.',
	'User has been created.' => 'Kasutaja on edukalt lisatud.',
	'Hashed' => 'Häshitud (Hashed)',
	'Column' => 'Veerg',
	'Routine' => 'Protseduur',
	'Grant' => 'Anna',
	'Revoke' => 'Eemalda',
	'MySQL version: %s through PHP extension %s' => 'MySQL versioon: %s, kasutatud PHP moodul: %s',
	'Logged as: %s' => 'Sisse logitud: %s',
	'Too big POST data. Reduce the data or increase the "post_max_size" configuration directive.' => 'POST-andmete maht on liialt suur. Palun vähendage andmeid või suurendage "post_max_size" php-seadet.',
	'Move up' => 'Liiguta ülespoole',
	'Move down' => 'Liiguta allapoole',
	'Export' => 'Ekspordi',
	'skip' => 'ignoreeri',
	'Tables' => 'Tabelid',
	'Structure' => 'Struktuur',
	'Data' => 'Andmed',
	'Output' => 'Väljund',
	'open' => 'näita brauseris',
	'save' => 'salvesta failina',
	'Format' => 'Formaat',
	'SQL' => 'SQL',
	'CSV' => 'CSV',
	'Functions' => 'Funktsioonid',
	'Aggregation' => 'Liitmine',
	'Event has been dropped.' => 'Sündmus on edukalt kustutatud.',
	'Event has been altered.' => 'Sündmuse andmed on edukalt uuendatud.',
	'Event has been created.' => 'Sündmus on edukalt loodud.',
	'Alter event' => 'Muuda sündmuse andmeid',
	'Create event' => 'Loo uus sündmus (EVENT)',
	'Start' => 'Alusta',
	'End' => 'Lõpeta',
	'Every' => 'Iga',
	'Status' => 'Staatus',
	'On completion preserve' => 'Lõpetamisel jäta sündmus alles',
	'Events' => 'Sündmused (EVENTS)',
	'Schedule' => 'Ajakava',
	'At given time' => 'Antud ajahetkel',
	'Save and continue edit' => 'Salvesta ja jätka muutmist',
	'original' => 'originaal',
	'Tables have been truncated.' => 'Validud tabelid on edukalt tühjendatud.',
	'Tables have been moved.' => 'Valitud tabelid on edukalt liigutatud.',
	'Tables have been dropped.' => 'Valitud tabelid on edukalt kustutatud.',
	'Tables and views' => 'Tabelid ja vaated',
	'Engine' => 'Implementatsioon',
	'Collation' => 'Tähetabel',
	'Data Length' => 'Andmete pikkus',
	'Index Length' => 'Indeksi pikkus',
	'Data Free' => 'Vaba ruumi',
	'Rows' => 'Ridu',
	',' => ',',
	'Analyze' => 'Analüüsi',
	'Optimize' => 'Optimeeri',
	'Check' => 'Kontrolli',
	'Repair' => 'Paranda',
	'Truncate' => 'Tühjenda',
	'Move to other database' => 'Liiguta teise andmebaasi',
	'Move' => 'Liiguta',
	'%d item(s) have been affected.' => array('Mõjutatud kirjeid: %d.', 'Mõjutatud kirjeid: %d.'),
	'whole result' => 'Täielikud tulemused',
	'clone' => 'Klooni',
	'Clone' => 'Kloon',
	'Maximum number of allowed fields exceeded. Please increase %s and %s.' => 'Maksimaalne väljade arv ületatud. Palun suurendage %s ja %s.',
	'Partition by' => 'Partitsiooni',
	'Partitions' => 'Partitsioonid',
	'Partition name' => 'Partitsiooni nimi',
	'Values' => 'Väärtused',
	'%d row(s) has been imported.' => array('Imporditi %d rida', 'Imporditi %d rida'),
	'Table structure' => 'Tabeli struktuur',
	'(anywhere)' => '(vahet pole)',
	'CSV Import' => 'Impordi CSV',
	'Import' => 'Impordi',
	'Stop on error' => 'Peatuda vea esinemisel',
	'Select table' => 'Vali tabel',
);
